package swinggl;



import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

import java.util.List;
import java.util.LinkedList;
import java.util.Iterator;
import java.util.ListIterator;

/**
 *
 * @author Giovanni Alestra
 * @version 1.0
 *
 * Classe Principale - Consente la generazione delle interfacce grafiche
 * formate anche da più finestre, l'assegnamento di nomi ai componenti grafici
 * ed il riferimento a questi per modifiche in ottica di dinamicità 
 * dell'interfaccia mediante il nome assegnato
 */

public class SwingGL {

    List objects;
    JFileChooser filechooser;
    
    /**
     * Costruttore
     */
    public SwingGL () {
        objects = new LinkedList();
        filechooser = new JFileChooser();
    }
    
    /**
     * Restituisce un riferimento di tipo Object all'oggetto 
     * (componente grafico) a cui ci si riferisce mediante una stringa
     * che è il nome dell'oggetto
     * 
     * @param name
     * @return Object 
     */
    public Object getObject ( String name ) {
        Object pointer;
        
        for ( int i=0; i<objects.size(); i++) {
            pointer = objects.get(i);
            if ( ((SwingGLObject) pointer).name.equals(name) ) return ((SwingGLObject) pointer).object;
        }
        
        return null;
    }
    
    private boolean addObject ( SwingGLObject obj ) {
        Object o = getObject (obj.name);
        if ( o != null ) return false;
        objects.add(obj);
        return true;
    }
    
    /**
     * Permette la creazione e visualizzazione di una finestra
     * 
     * @param name Stringa contenente il nome che si vuole assegnare alla finestra
     * @param title Stringa che indica il titolo che verrà visualizzato nella finestra
     * @param x Posizione X nello schermo
     * @param y Posizione Y nello schermo
     * @param width Larghezza della finestra
     * @param heightAltezza della finestra
     */
    
    public void newWindow ( String name, String title, int x, int y, int width, int height ) throws SwingGLException { 
        SwingGLObject newObj = new SwingGLObject ( name, new SwingGLWindow ( title, x,y,width,height ));
        
        if ( !addObject(newObj) ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
        
    }
    
    /**
     * Permette di visualizzare un pannello sul quale creare altri oggetti grafici
     *
     * @param name Stringa che contine il nome che si vuole assegnare al pannello
     * @param container Contenitore del pannello tipicamente una finestra
     * @param width Esprime la Larghezza del Pannello in pixel
     * @param height Esprime l'Altezza del Pannello in pixel
     */
    
    public void newPanel ( String name, String container, int width, int height ) throws SwingGLException {
        Object cont = getObject (container);
            if ( cont == null ) throw new SwingGLException (2, "Nome oggetto contenitore errato. Non esiste un oggetto con il nome " + container);
        Object ogg = getObject ( name );
            if ( ogg != null ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
            
        SwingGLPanel panel = new SwingGLPanel ();
        panel.setPreferredSize(new Dimension(width,height));
        JScrollPane scrollpane = new JScrollPane (panel);
        scrollpane.setAlignmentY(20);
        SwingGLObject newObj = new SwingGLObject ( name, panel );    
        if ( !addObject(newObj) ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
        ((java.awt.Container) cont).add( ((java.awt.Component)scrollpane));
        scrollpane.repaint();
    }
    
    /**
     * Cosente la visualizzazione di una etichetta ed il suo posizionamento
     * relativo al contenitore 
     * 
     * @param name Stringa contenente il nome che si vuole assegnare all'etichetta
     * @param container Stringa che indica il nome del contenitore tipicamente un pannello
     * @param text Stringa Testo dell'etichetta
     * @param x Posizione X relativa al contenitore
     * @param y Posizione Y relativa la contenitore
     * @param width Larghezza dell'etichetta
     * @param height Altezza dell'etichetta
     */
    
    public void newLabel ( String name, String container, String text, int x, int y, int width, int height ) throws SwingGLException {
        Object cont = getObject (container);
            if ( cont == null ) throw new SwingGLException (2, "Nome oggetto contenitore errato. Non esiste un oggetto con il nome " + container);
        Object ogg = getObject ( name );
            if ( ogg != null ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
        
        SwingGLLabel label = new SwingGLLabel (text, x, y, width, height);
        SwingGLObject newObj = new SwingGLObject ( name, label );    
         if ( !addObject(newObj) ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
        ((java.awt.Container) cont).add( ((java.awt.Component)label));
        
    }
    
    /**
     * Consente la creazione e visualizzazione di un Bottone su cui si può cliccare
     * 
     * @param name Stringa contenente il nome che si vuole assegnare al Bottone
     * @param container Stringa contente il nome del contenitore tipicamente un pannello
     * @param text Testo del Bottone
     * @param x Posizione X relativa al contenitore
     * @param y Posizione Y relativa al contenitore
     * @param width Larghezza del Bottone
     * @param height Altezza del bottone
     * @param e Classe che implementa SwingGLEvent per la gestione dell'evento Click settabile su null se non si vuole gestire l'evento
     * 
     */
    
     public void newButton ( String name, String container, String text, int x, int y, int width, int height, SwingGLEvent e ) throws SwingGLException  {
        Object cont = getObject (container);
            if ( cont == null ) throw new SwingGLException (2, "Nome oggetto contenitore errato. Non esiste un oggetto con il nome " + container);
         Object ogg = getObject ( name );
            if ( ogg != null ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
       
        SwingGLButton button = new SwingGLButton (text, x, y, width, height, e);
        SwingGLObject newObj = new SwingGLObject ( name, button );    
           if ( !addObject(newObj) ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
        ((java.awt.Container) cont).add( ((java.awt.Component)button));
        
    }
     
     /** 
       * Permette la visualizzazione di una Text Area
       * 
       * @param name Nome da dare al componente
       * @param container Nome del contenitore tipicamente un pannello
       * @param text Testo di default
       * @param x Posizione X
       * @param y Posizione Y
       * @param width Larghezza del componente
       * @param height Altezza del Componente
       */
          
      public void newTextArea ( String name, String container, String text, int x, int y, int width, int height ) throws SwingGLException {
        Object cont = getObject (container);
         if ( cont == null ) throw new SwingGLException (2, "Nome oggetto contenitore errato. Non esiste un oggetto con il nome " + container);
        Object ogg = getObject ( name );
            if ( ogg != null ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
       
         
        SwingGLTextArea textarea = new SwingGLTextArea (text, x, y, width, height);
        SwingGLObject newObj = new SwingGLObject ( name, textarea );    
        if ( !addObject(newObj) ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
        ((java.awt.Container) cont).add( ((java.awt.Component)textarea));
        textarea.repaint();
        
    }
      
      /** 
       * Permette la visualizzazione di un Text Field
       * 
       * @param name Nome da dare al componente
       * @param container Nome del contenitore tipicamente un pannello
       * @param text Testo di default
       * @param x Posizione X
       * @param y Posizione Y
       * @param width Larghezza del componente
       * @param height Altezza del Componente
       */
      
      public void newTextField ( String name, String container, String text, int x, int y, int width, int height ) throws SwingGLException {
        Object cont = getObject (container);
         if ( cont == null ) throw new SwingGLException (2, "Nome oggetto contenitore errato. Non esiste un oggetto con il nome " + container);
        Object ogg = getObject ( name );
            if ( ogg != null ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
       
        
        SwingGLTextField textfield = new SwingGLTextField (text, x, y, width, height);
        SwingGLObject newObj = new SwingGLObject ( name, textfield );    
        if ( !addObject(newObj) ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
        ((java.awt.Container) cont).add( ((java.awt.Component)textfield));
        textfield.repaint();
        
    }

      /**
       * Permette la visualizzazione di un campo Password
       * 
       * @param name Nome da dare al componente
       * @param container Nome del contenitore tipicamente un pannello
       * @param x Posizione x
       * @param y Posizione y
       * @param width Larghezza del componente
       * @param height Altezza del componente
       */
      
      public void newPasswordField ( String name, String container, int x, int y, int width, int height ) throws SwingGLException {
        Object cont = getObject (container);
          if ( cont == null ) throw new SwingGLException (2, "Nome oggetto contenitore errato. Non esiste un oggetto con il nome " + container);
        Object ogg = getObject ( name );
            if ( ogg != null ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
       
        SwingGLPasswordField passwordfield = new SwingGLPasswordField (x, y, width, height);
        SwingGLObject newObj = new SwingGLObject ( name, passwordfield );    
        if ( !addObject(newObj) ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
        ((java.awt.Container) cont).add( ((java.awt.Component)passwordfield));
        passwordfield.repaint();
        
    }

      /**
       * Permette di visualizzare un CheckBox
       * 
       * @param name Nome del componente
       * @param container Nome del contenitore tipicamente un pannello
       * @param text Testo inerente alla selezione
       * @param x Posizione x
       * @param y Posizione y
       * @param width Larghezza del componente
       * @param height Altezza del componente
       * @param selected Selezionato vero/falso
       */
      
      public void newCheckBox ( String name, String container, String text, int x, int y, int width, int height, boolean selected ) throws SwingGLException  {
        Object cont = getObject (container);
          if ( cont == null ) throw new SwingGLException (2, "Nome oggetto contenitore errato. Non esiste un oggetto con il nome " + container);
        Object ogg = getObject ( name );
            if ( ogg != null ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
       
        SwingGLCheckBox checkbox = new SwingGLCheckBox (text, x, y, width, height, selected);
        SwingGLObject newObj = new SwingGLObject ( name, checkbox );    
        if ( !addObject(newObj) ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
        ((java.awt.Container) cont).add( ((java.awt.Component)checkbox));
        checkbox.repaint();   
    }
     
      public void newButtonGroup ( String name ) throws SwingGLException  {
          if ( !addObject(new SwingGLObject (name, new ButtonGroup()))) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
          
          
      }
      
      /**
       * Permette la visualizzazione di un radio button associato ad un button group
       * 
       * @param name Nome del componenete
       * @param container Nome del contenitore tipicamente un pannello
       * @param Group Nome del button group
       * @param text Testo inerente alla selezione
       * @param x Posizione x
       * @param y Posizione y
       * @param width Larghezza del componente
       * @param height Altezza del componente
       * @param selected Selezionato Vero/Falso 
       */
      
      public void newRadioButton ( String name, String container, String Group,String text, int x, int y, int width, int height, boolean selected ) throws SwingGLException  {
        Object cont = getObject (container);
          if ( cont == null ) throw new SwingGLException (2, "Nome oggetto contenitore errato. Non esiste un oggetto con il nome " + container);
        
        Object group = getObject (Group);
            if ( group == null ) throw new SwingGLException (2, "Nome oggetto errato. Non esiste un oggetto con il nome " + Group);
       
        Object ogg = getObject ( name );
           if ( ogg != null ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
       
            
        SwingGLRadioButton radiobutton = new SwingGLRadioButton (text, x, y, width, height, selected);
        SwingGLObject newObj = new SwingGLObject ( name, radiobutton );    
        if ( !addObject(newObj) ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
        ((java.awt.Container) cont).add( ((java.awt.Component)radiobutton));
        radiobutton.repaint();
        ((ButtonGroup) group).add(radiobutton);
    }

      /**
       * Permette la visualizzazione di un ComboBox
       * 
       * @param name Nome da dare al Componente
       * @param container Nome del contenitore tipicamente un pannello
       * @param items Lista dei valori selezionabili
       * @param x Posizione x
       * @param y Posizione y
       * @param width Larghezza del componente
       * @param height Altezza del componente
       */
        public void newComboBox ( String name, String container, String[] items, int x, int y, int width, int height ) throws SwingGLException  {
        Object cont = getObject (container);
           if ( cont == null ) throw new SwingGLException (2, "Nome oggetto contenitore errato. Non esiste un oggetto con il nome " + container);
       Object ogg = getObject ( name );
           if ( ogg != null ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
       
           
        SwingGLComboBox combobox = new SwingGLComboBox (items, x, y, width, height);
        SwingGLObject newObj = new SwingGLObject ( name, combobox );    
        if ( !addObject(newObj) ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
        ((java.awt.Container) cont).add( ((java.awt.Component)combobox));
        combobox.repaint();   
    }
 
        /**
         * Permette la visualizzazione di un TabbedPane
         * 
         * @param name Nome da dare al componente
         * @param container Nome del contenitore tipicamente un pannello
         * @param x Posizione x
         * @param y Posizione y
         * @param width Larghezza del componente
         * @param height Altezza del componente
         */
        
        public void newTabbedPane ( String name, String container, int x, int y, int width, int height ) throws SwingGLException {
        Object cont = getObject (container);
               if ( cont == null ) throw new SwingGLException (2, "Nome oggetto contenitore errato. Non esiste un oggetto con il nome " + container);
       Object ogg = getObject ( name );
           if ( ogg != null ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
    
        SwingGLTabbedPane tabbedpane = new SwingGLTabbedPane (x, y, width, height);
        SwingGLObject newObj = new SwingGLObject ( name, tabbedpane );    
        if ( !addObject(newObj) ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
        ((java.awt.Container) cont).add( ((java.awt.Component)tabbedpane));
        tabbedpane.repaint();
    }

        /**
         * Permette di aggiugere un pannello ad un TabbedPane
         * 
         * @param tabbedpane Nome del TabbedPane
         * @param name Nome del pannello che si vuole aggiungere
         * @param title Titolo del pannello
         */
        
        public void addTabToTabbedPane (String tabbedpane, String name, String title ) throws SwingGLException {
            Object tabpane = getObject (tabbedpane);
            if ( tabpane == null ) throw new SwingGLException (2, "Nome oggetto errato. Non esiste un oggetto con il nome " + tabbedpane);
          
            Object ogg = getObject ( name );
           if ( ogg != null ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
    
            JPanel panel = new JPanel();
            panel.setLayout(null);
            ((JTabbedPane) tabpane).addTab (title,null,panel, "");
            objects.add(new SwingGLObject (name, panel));
        }

        /**
         * Aggiunge una menù bar ad una finestra
         * 
         * @param name Nome da dare al componente
         * @param window Nome della finestra
         */
        public void addMenuBarToWindow ( String name, String window ) throws SwingGLException {
            Object win = getObject (window);
            if ( win == null ) throw new SwingGLException (2, "Nome oggetto errato. Non esiste un oggetto con il nome " + window);
           
             Object ogg = getObject ( name );
           if ( ogg != null ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
                
            JMenuBar menubar = new JMenuBar();
            objects.add(new SwingGLObject(name,menubar));
            ((JFrame) win).setJMenuBar(menubar);           
         }
        
        /**
         * Aggiunge un menù alla finestra
         * 
         * @param menubar Nome della menùbar
         * @param name Nome del menu che si stà aggiungendo
         * @param menuItems Campi del menù
         * @param e Gestore dell'evento click sul menù
         */
        
        public void addMenuToWindow ( String menubar, String name, String[] menuItems , SwingGLEvent e ) throws SwingGLException {
            Object menuBar = getObject (menubar);
            if ( menuBar == null ) throw new SwingGLException (2, "Nome oggetto errato. Non esiste un oggetto con il nome " + menubar);;
            JMenu menu = new JMenu( name );
            ((JMenuBar) menuBar ).add(menu);
            for ( int i=0; i< menuItems.length; i++ ) {
                menu.add(new SwingGLMenuItem(menuItems[i],e));
            };
            
        }
        
        /**
         * Visualizza una OpenFileDialog
         * 
         * @param title Titolo della finestra
         * @return String Nome del file selezionato 
         */
        
        public String ShowOpenFileDialog (String title)
        {
            filechooser.setDialogTitle(title);
            
            int returnval = filechooser.showOpenDialog(null);
            if ( returnval == JFileChooser.APPROVE_OPTION ) {
                return filechooser.getSelectedFile().getAbsolutePath();
            } else return "";
                
             
        }
        
        /**
         * Visualizza una FileSaveDialog
         * 
         * @param title Titolo della finestra di dialogo
         * @return String Nome del file sul quale salvare salvare
         */
        
        public String ShowSaveFileDialog (String title) {
            filechooser.setDialogTitle(title);
            
            int returnval = filechooser.showSaveDialog(null);
            if ( returnval == JFileChooser.APPROVE_OPTION ) {
                return filechooser.getSelectedFile().getAbsolutePath();
            } else return "";
            
        }

        /**
         * Permette la visualizzazione di un messaggio
         * 
         * @param message Messaggio da visualizzare
         */
        public void ShowMessageDialog (String message) {
            JOptionPane.showMessageDialog(null, message);
       }

        /** Permette la visualizzazione di una finestra di input
         * 
         * @param message Messaggio da visualizzare
         * @return Stringa di risposta da parte dell'utente
         */
        
        public String ShowInputDialog (String message) {
            return JOptionPane.showInputDialog(null, message);
       }

        /**
         * Applicabile a TextField e TextArea ritorna una stringa contanente il testo digitato sul componente
         * 
         * @param name Nome del Componente
         * @return Testo Digitato
         */
        
        public String GetText (String name) throws SwingGLException {
            Object text = getObject (name);
            if ( text == null ) throw new SwingGLException (2, "Nome oggetto errato. Non esiste un oggetto con il nome " + name);
            
            if (text instanceof SwingGLTextField) {
                return ((SwingGLTextField) text).getText();
            }  else if  (text instanceof SwingGLTextArea) {
                return ((SwingGLTextArea) text).getText();
            }   else { throw new SwingGLException ( 3, "Get da un oggetto di tipo errato");}    
          
          
        }
        
        
        /**
         * Applicabile a PasswordField ritorna un vettore di caratteri che è la password digitata
         * 
         * @param name Nome del componenente
         * @return Password digitata
         */
        
        public char[] GetPassword ( String name ) throws SwingGLException {
            Object pw = getObject (name);
            if ( pw == null ) throw new SwingGLException (2, "Nome oggetto errato. Non esiste un oggetto con il nome " + name);
            
            if (pw instanceof SwingGLPasswordField) {
                return ((SwingGLPasswordField) pw).getPassword();
            }   else { throw new SwingGLException ( 3, "Get da un oggetto di tipo errato");}    
                }
        
        /**
         * Applicabile a ComboBox ritorna il testo selezionato
         * 
         * @param name Nome del Componenete
         * @return Testo Selezionato
         */
        
        public String GetSelection ( String name ) throws SwingGLException {
             Object text = getObject (name);
            if ( text == null ) throw new SwingGLException (2, "Nome oggetto errato. Non esiste un oggetto con il nome " + name);
            
            if (text instanceof SwingGLComboBox) {
                return ((SwingGLComboBox) text).getSelectedItem().toString();
            }   else { throw new SwingGLException ( 3, "Get da un oggetto di tipo errato");}     
          
        }

        /**
         * Applicabile a CheckBox e RadioButton ritorna se l'elemento è stato selezionato 
         * 
         * @param name Nome del Componente
         * @return Booleano Vero/Falso
         */
        
        public boolean GetSelected ( String name ) throws SwingGLException {
            Object obj = getObject (name);
            if ( obj == null ) throw new SwingGLException (2, "Nome oggetto errato. Non esiste un oggetto con il nome " + name);
            
            if (obj instanceof SwingGLCheckBox) {
                return !(((SwingGLCheckBox) obj).getSelectedObjects() == null);
            } else if (obj instanceof SwingGLRadioButton) {
                return !(((SwingGLRadioButton) obj).getSelectedObjects() == null);
                
            }   else { throw new SwingGLException ( 3, "Get da un oggetto di tipo errato");} 
        }
       
        
        /**
         * 
         * Applicabile a TextField e TextArea setta il testo del componente
         * 
         * @param name Nome del componente
         * @param text testo da settare
         */
        
        public void SetText (String name, String text) throws SwingGLException {
            Object obj = getObject (name);
            if ( obj == null ) throw new SwingGLException (2, "Nome oggetto errato. Non esiste un oggetto con il nome " + name);
            
            if (obj instanceof SwingGLTextField) {
                ((SwingGLTextField) obj).setText(text); return;
            }  else if  (obj instanceof SwingGLTextArea) {
               ((SwingGLTextArea) obj).setText(text); return;
            }   else { throw new SwingGLException ( 4, "Set su di un oggetto di tipo errato");}
               
        }
       
        /** 
         * Applicabile a ComboBox setta il testo della possibile selezione
         * @param name Nome del componente
         * @param index Intero che indica la posizione del testo da settare nel vettore String[] Items
         */
        
        public void SetSelection ( String name, int index ) throws SwingGLException {
             Object obj = getObject (name);
            if ( obj == null ) throw new SwingGLException (2, "Nome oggetto errato. Non esiste un oggetto con il nome " + name);
            
            if (obj instanceof SwingGLComboBox) {
                ((SwingGLComboBox) obj).setSelectedIndex(index);
            }   else { throw new SwingGLException ( 4, "Set su di un oggetto di tipo errato");}
        }

        /**
         * Applicabile a CheckBox e RadioButton setta la selezione
         * @param name Nome del Componente
         * @param value Booleano Vero/Falso
         */
        
        public void SetSelected ( String name, boolean value ) throws SwingGLException {
            Object obj = getObject (name);
            if ( obj == null ) throw new SwingGLException (2, "Nome oggetto errato. Non esiste un oggetto con il nome " + name);
            
            if (obj instanceof SwingGLCheckBox) {
                ((SwingGLCheckBox) obj).setSelected(value);
            } else if (obj instanceof SwingGLRadioButton) {
                ((SwingGLRadioButton) obj).setSelected(value);
                
            }   else { throw new SwingGLException ( 4, "Set su di un oggetto di tipo errato");}
         
          }
       
        /**
         * Aggiunge un DeskTop Pane alla Finestra
         * 
         * @param name Nome del Desktop Pane
         * @param window Nome della Finestra
         * @throws SwingGLException 
         */
        
        public void AddDesktopPaneToWindow ( String name, String window ) throws SwingGLException {
             Object ogg = getObject ( name );
           if ( ogg != null ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
        
             Object win = getObject (window);
            if ( win == null ) throw new SwingGLException (2, "Nome oggetto errato. Non esiste un oggetto con il nome " + window);
         
            JDesktopPane desktop = new JDesktopPane();
            if ( win instanceof SwingGLWindow ) ((SwingGLWindow) win).setContentPane(desktop);
            else throw new SwingGLException (5, "Oggetto di tipo Errato : Era ettaso SwingGLWindow");
            objects.add(new SwingGLObject ( name, desktop));
           
           
        }
        
        /**
         * Aggiunge un InternalFrame ad un Desktop Pane
         * 
         * @param name Nome dell'Internal Frame
         * @param desktoppane Nome del Desktop Pane
         * @param title Titolo dell'Internal Frame
         * @param x Posizione x
         * @param y Posizione y
         * @param width Larghezza del Frame
         * @param height Altezza del Frame
         * @return Oggetto di tipo SwingGL 
         * @throws SwingGLException 
         */
        
        public SwingGL newInternalFrame (String name, String desktoppane, String title, int x, int y, int width, int height ) throws SwingGLException {
           Object desk = getObject (desktoppane);
            if ( desk == null ) throw new SwingGLException (2, "Nome oggetto errato. Non esiste un oggetto con il nome " + desktoppane);
           
            Object ogg = getObject ( name );
           if ( ogg != null ) throw new SwingGLException ( 1, "Nome oggetto esistente e non univoco" );
              
           SwingGLInternalFrame iframe = new SwingGLInternalFrame ( name, title, x,y,width,height);
           ((JDesktopPane) desk).add(iframe);
           objects.add(new SwingGLObject(name,iframe));
           return iframe.getGraphicInteface();
            
        }
        
        /**
         * Restituisce l'oggeto SwingGL di un Internal Frame
         * 
         * @param internalFrame Nome dell'Internal Frame
         * @return
         * @throws SwingGLException 
         */
        
        public SwingGL getGraphicInteface ( String internalFrame ) throws SwingGLException {
            Object ogg = getObject ( internalFrame );
           if ( ogg == null ) throw new SwingGLException ( 2, "Nome Errato! Oggetto inesistente" );
           
           if ( ogg instanceof SwingGLInternalFrame ) return ((SwingGLInternalFrame) ogg).getGraphicInteface();
           else throw new SwingGLException ( 5, "Oggetto di tipo Errato. Era Atteso SwingGLInternalFrame" );
            
        }
}


